from krita import *
from PyQt5.QtWidgets import *
from PyQt5.QtCore import Qt

print("Buttonz plugin: Starting to load", file=sys.stderr)


class ButtonzDocker(DockWidget):
    def __init__(self):
        super().__init__()
        self.setWindowTitle("Buttonz Booster")
        
        # Create main widget
        main_widget = QWidget(self)
        self.setWidget(main_widget)
        
        # Create a vertical layout for the whole docker
        main_layout = QVBoxLayout()
        main_widget.setLayout(main_layout)
        
        # Add description label
        desc_label = QLabel("Create new document with preset sizes")
        desc_label.setWordWrap(True)
        main_layout.addWidget(desc_label)
        
        # Create grid layout for buttons
        grid_layout = QGridLayout()
        grid_layout.setSpacing(4)  # Add some space between buttons
        
        # Common preset sizes (width x height in pixels)
        self.presets = [
            ("Square Social Media", 2048, 2048),
            ("Instagram Story", 1080, 1920),
            ("Desktop Wallpaper", 3840, 2160),
            ("Comic Page", 2480, 3508),
            ("Concept Art", 3840, 2160),
            ("Icon", 512, 512),
            ("Twitter Header", 1500, 500),
            ("YouTube Thumbnail", 1280, 720)
        ]
        
        # Calculate number of columns (3) and rows
        COLS = 3
        num_presets = len(self.presets)
        
        # Create buttons and add them to grid
        for index, (name, width, height) in enumerate(self.presets):
            btn = QPushButton(f"{name}\n{width}*{height}")
            btn.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Preferred)
            btn.clicked.connect(lambda checked, w=width, h=height: self.create_new_document(w, h))
            
            # Calculate row and column positions
            row = index // COLS
            col = index % COLS
            
            grid_layout.addWidget(btn, row, col)
        
        # Add the grid layout to the main layout
        main_layout.addLayout(grid_layout)
        
        # Add stretch to push everything to top
        main_layout.addStretch()
        
        # Set some styling to make it look better
        self.setStyleSheet("""
            QPushButton {
                min-height: 50px;
                padding: 4px;
                text-align: center;
            }
        """)
    
    def canvasChanged(self, canvas):
        """
        This is called whenever the current canvas changes in Krita.
        Required implementation from DockWidget base class.
        
        Args:
            canvas: The new canvas object or None
        """
        pass
        
    def create_new_document(self, width, height):
        # Get Krita instance
        krita_instance = Krita.instance()
        
        # Create new document
        document = krita_instance.createDocument(
            width, height,
            "New Document",
            "RGBA",
            "U8",
            "",
            300.0  # 300 DPI
        )
        
        # Open the document
        krita_instance.activeWindow().addView(document)

def createDocker():
    return ButtonzDocker()

Application.addDockWidgetFactory(
    DockWidgetFactory(
        "buttonz",
        DockWidgetFactoryBase.DockRight,
        createDocker
    )
)
